@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.15'; # VERSION
+our $VERSION = '0.16'; # VERSION
 
 require Exporter;
 our @ISA       = qw(Exporter);
@@ -325,7 +325,7 @@ sub bash_complete_spec_arg {
             );
         }
 
-        my $ah0 = $arg_spec->{attr_hashes}[0];
+        my $ah0 = $arg_spec->{clause_sets}[0];
         if ($ah0->{in}) {
             $log->tracef("completing arg value from 'in' spec");
             return _complete_array($word, $ah0->{in});
@@ -358,7 +358,7 @@ sub bash_complete_spec_arg {
             } else {
                 @w = ("--$_");
             }
-            my $aliases = $args_spec->{$_}{attr_hashes}[0]{arg_aliases};
+            my $aliases = $args_spec->{$_}{clause_sets}[0]{arg_aliases};
             if ($aliases) {
                 while (my ($al, $alinfo) = each %$aliases) {
                     push @w,
@@ -400,7 +400,7 @@ Sub::Spec::BashComplete - Provide bash completion for Sub::Spec::CmdLine program
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
